==> trade-center-api-0.8.9-20170329.093023-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteMainOrderFlowworkService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * 主订单异步审核接口
 * Created by yansen on 16/9/29.
 */
public interface RemoteMainOrderFlowworkService {
    /**
     * @param orderId
     * @return
     */
    public DubboResult<Void> doAuditPass(Long orderId);

    /**
     * @param orderId
     * @return
     */
    public DubboResult<Void> doAuditReject(Long orderId);


    /**
     * @param orderId
     * @param expressName
     * @param expressId
     * @return
     */
    public DubboResult<Boolean> executeObjectSend(Long orderId, String expressName, String expressId);

    /**
     * @param orderId
     * @param reason4consumer
     * @return
     */
    public DubboResult<Boolean> executeObjectCancel(Long orderId, String reason4consumer);

    /**
     * @param orderId
     * @param errorMassage
     * @return
     */
    DubboResult<Boolean> adminCanceOrder(Long orderId, String errorMassage);

    /**
     * @param orderId
     * @param deliverInfo
     * @return
     */
    DubboResult<Boolean> executeManualLotterySend(Long orderId, String deliverInfo);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> forceVirtual2SupplierSuccess(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> forceVirtual2SupplierFail(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> mngForceSupplierSuccess(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> mngForceSupplierFail(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @return
     */
    DubboResult<Boolean> killOrderMakeSuccess(Long orderId);

    /**
     *
     * @param orderId
     * @return
     */
    DubboResult<Boolean> killOrderMakeFail(Long orderId);

    /**
     *
     * @param orderId
     * @param consumerId
     * @param allowInput
     * @param allowInputTips
     * @return
     */
    DubboResult<Boolean> updateAllowInputAndTips(Long orderId, Long consumerId, Boolean allowInput, String allowInputTips);
}

==> trade-center-api-2.4.15-20220303.073733-10-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteMainOrderFlowworkService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.SendDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.List;

/**
 * 主订单异步审核接口
 * Created by yansen on 16/9/29.
 */
@AdvancedFeignClient
public interface RemoteMainOrderFlowworkService {
    /**
     * 开发者审核通过
     * @param orderId
     * @return
     */
    public DubboResult<Void> doAuditPass(Long orderId);

    /**
     * @param orderId
     * @return
     */
    public DubboResult<Void> doAuditReject(Long orderId);

    /**
     * 开发者审核拒绝
     * @param orderId
     * @param reason
     * @return
     */
    @RequestMapping("/doAuditReject1")
    DubboResult<Void> doAuditReject(Long orderId, String reason);

    /**
     * @param orderId
     * @param expressName
     * @param expressId
     * @return
     */
    public DubboResult<Boolean> executeObjectSend(Long orderId, String expressName, String expressId);

    /**
     *
     * 批量发货
     * @param orders
     */
    int batchExecuteObjectSend(List<SendDto> orders);

    /**
     * @param orderId
     * @param reason4consumer
     * @return
     */
    public DubboResult<Boolean> executeObjectCancel(Long orderId, String reason4consumer);

    public DubboResult<Boolean> executeObjectCancelV1(Long orderId,List<Long> orderItemIds, String reason4consumer);

    /**
     * @param orderId
     * @param errorMassage
     * @return
     */
    DubboResult<Boolean> adminCanceOrder(Long orderId, String errorMassage);

    /**
     * @param orderId
     * @param deliverInfo
     * @return
     */
    DubboResult<Boolean> executeManualLotterySend(Long orderId, String deliverInfo);

    /**
     *
     * 批量发货
     * @param orders
     */
    int batchExesuteManualLotterySend(List<SendDto> orders);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> forceVirtual2SupplierSuccess(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> forceVirtual2SupplierFail(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> mngForceSupplierSuccess(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Boolean> mngForceSupplierFail(Long orderId, String error4admin, String error4developer, String error4consumer);

    /**
     * @param orderId
     * @return
     */
    DubboResult<Boolean> killOrderMakeSuccess(Long orderId);

    /**
     *
     * @param orderId
     * @return
     */
    DubboResult<Boolean> killOrderMakeFail(Long orderId);

    /**
     *
     * @param orderId
     * @param consumerId
     * @param allowInput
     * @param allowInputTips
     * @return
     */
    DubboResult<Boolean> updateAllowInputAndTips(Long orderId, Long consumerId, Boolean allowInput, String allowInputTips);

	/**
     * 虚拟商品重试
     * @param orderIds
     * @return
     */
    Boolean   virturalOrderRetry(List<Long> orderIds);

    @RequestMapping("/executeObjectSend1")
    Boolean executeObjectSend(SendDto sendDto);
}
